@@ -25,9 +25,6 @@
 #include "as-app-private.h"
 #include "as-utils.h"
 
-/**
- * as_app_desktop_key_get_locale:
- */
 static gchar *
 as_app_desktop_key_get_locale (const gchar *key)
 {
@@ -46,9 +43,6 @@ as_app_desktop_key_get_locale (const gchar *key)
 	return locale;
 }
 
-/**
- * as_app_infer_file_key:
- **/
 static gboolean
 as_app_infer_file_key (AsApp *app,
 		       GKeyFile *kf,
@@ -96,9 +90,6 @@ as_app_infer_file_key (AsApp *app,
 	return TRUE;
 }
 
-/**
- * _as_utils_is_stock_icon_name_fallback:
- **/
 static gboolean
 _as_utils_is_stock_icon_name_fallback (const gchar *name)
 {
@@ -117,9 +108,6 @@ _as_utils_is_stock_icon_name_fallback (const gchar *name)
 	return FALSE;
 }
 
-/**
- * as_app_parse_file_key:
- **/
 static gboolean
 as_app_parse_file_key (AsApp *app,
 		       GKeyFile *kf,
@@ -214,10 +202,6 @@ as_app_parse_file_key (AsApp *app,
 				}
 			}
 
-			/* not a standard category */
-			if (g_str_has_prefix (list[i], "X-"))
-				continue;
-
 			/* check the category is valid */
 			if (!as_utils_is_category_id (list[i]))
 				continue;
@@ -363,12 +347,19 @@ as_app_parse_file_key (AsApp *app,
 			as_app_add_veto (app, "X-AppStream-Ignore");
 	}
 
+	/* Add any external attribute as metadata to the application */
+	if (g_str_has_prefix (key, "X-")) {
+		g_autofree char *value = NULL;
+		value = g_key_file_get_string (kf,
+					       G_KEY_FILE_DESKTOP_GROUP,
+					       key,
+					       NULL);
+		as_app_add_metadata (app, key, value);
+	}
+
 	return TRUE;
 }
 
-/**
- * as_app_parse_file_key_fallback_comment:
- **/
 static gboolean
 as_app_parse_file_key_fallback_comment (AsApp *app,
 					GKeyFile *kf,
@@ -403,9 +394,6 @@ as_app_parse_file_key_fallback_comment (AsApp *app,
 	return TRUE;
 }
 
-/**
- * as_app_parse_desktop_file:
- **/
 gboolean
 as_app_parse_desktop_file (AsApp *app,
 			   const gchar *desktop_file,
